;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                        ;;
;;             Center for Spoken Language Understanding                   ;;
;;        Oregon Graduate Institute of Science & Technology               ;;
;;                         Portland, OR USA                               ;;
;;                        Copyright (c) 2000                              ;;
;;                                                                        ;;
;;      This module is not part of the CSTR/University of Edinburgh       ;;
;;               release of the Festival TTS system.                      ;;
;;                                                                        ;;
;;  In addition to any conditions disclaimers below, please see the file  ;;
;;  "license_ogi_tts.txt" distributed with this software for information  ;;
;;  on usage and redistribution, and for a DISCLAIMER OF ALL WARRANTIES.  ;;
;;                                                                        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Set up diphone voice
;;;  Male American English (Mike Macon), design 000821 by Vincent Pagel at OGI


;; load unit selection routine
(set! mwm5_diphone_dir (cdr (assoc 'mwm5_diphone voice-locations)))
(set! load-path (cons (path-append mwm5_diphone_dir "festvox") load-path))
(require 'ogi_mwm5unitsel)

(require 'ogi_configure_voice)

;; select voice
;; this defines all the modules to use when synthesizing text using the current voice
(define (voice_mwm5_diphone)
  "(voice_mwm5_diphone)
  Set up the current voice to be an American male MWM using
  the MWM diphone set and OGIresLPC (recording 000821)."
  
  ;; set target average pitch and variation
  (set! mwm5_diphone_f0_mean 120)
  (set! mwm5_diphone_f0_std 20)
  
  ;; set unit selection method
  (set! OGI_unitsel mwm5_OGI_di_unitsel)
  
  ;; use the grouped file by default
  (set! ogi_grouped_or_ungrouped 'grouped)

  ;; use resLPC or sinLPC signal processing
  (set! ogi_resORsinLPC 'resLPC)

  ;; configure voice using defaults 
  (ogi_configure_voice 'mwm5_diphone)
  
  ;; overwrite defaults here:
  
  ;; For example, you can say 
  ;;   (Parameter.set 'Int_Method my_method)  to use another intonation method
  ;; or you can set 
  ;;   ogi_sinLPC_analysis_params to match a new voice
  ;;   and then call (initialize_sinLPC) to have the parameters take effect

  ;; initialize signal processing module (do this *after* changing any synth or analysis params)
  (initialize_OGIsynth)

)

;; proclaim voice
(proclaim_voice
 'mwm5_diphone
 '((language english)
   (gender male)
   (dialect american)
   (description
    "This voice provides an American English male voice using a
     residual excited or sinusoidal LPC diphone synthesis module created at
     OGI.  It uses a lexicon compiled from MOBY and CMU lexicons, and
     other trained modules used by CSTR voices.")
  (samplerate 22050)))

;; comment this out if you want changes in this file to take effect without restarting Festival
(provide 'mwm5_diphone)   
